package com.zanxiang.sdk.domain.vo;

import com.zanxiang.sdk.domain.enums.UserStatusEnum;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.io.Serializable;

/**
 * 响应信息主体
 *
 * @author ruoyi
 */
@Data
@NoArgsConstructor
@AllArgsConstructor
@Builder
public class ResultVO<T> implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * 成功code
     */
    public static final Integer CODE_SUCCESS = 200;

    /**
     * 成功msg
     */
    public static final String CODE_SUCCESS_MSG = "成功";

    /**
     * 错误码
     */
    private Integer code;

    /**
     * 错误消息
     */
    private String msg;

    /**
     * 返回数据
     */
    private T data;

    /**
     * 构造方法
     *
     * @param code : 错误码
     * @param msg  : 错误消息
     */
    private ResultVO(int code, String msg) {
        this(code, msg, null);
    }

    /**
     * 错误信息构造
     *
     * @param userStatusEnum : 错误枚举
     * @param <T>            : 泛型
     * @return : 返回
     */
    public static <T> ResultVO<T> fail(UserStatusEnum userStatusEnum) {
        return new ResultVO<>(userStatusEnum.getCode(), userStatusEnum.getMsg());
    }

    /**
     * 成功返回数据
     *
     * @param data : 数据
     * @param <T>  : 泛型
     * @return : 返回
     */
    public static <T> ResultVO<T> ok(T data) {
        return new ResultVO<>(CODE_SUCCESS, "成功", data);
    }
}
